/**
 * 
 */
package com.article.ldap.jndi.examples;

import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.SearchControls;
import javax.naming.directory.SearchResult;

import com.article.ldap.LDAPConstants;
import com.article.ldap.jndi.connection.JNDILDAPConnectionManager;
import com.article.ldap.jndi.connection.JNDILDAPConnectionManagerImpl;

/**
 * @author 		R. Thiru Ganesh Kumar
 * $name: 		SearchEntry.java     
 * $description:This example used to search an entry in LDAP Server using JNDI API
 *              search an entry under people group. 
 * 				  
 */
public class SearchEntry {

	/**
	 * This method used to search an entry in LDAP Server.
	 * @param args
	 */
	public static void main(String[] args) {
		final JNDILDAPConnectionManager jndiManager = new JNDILDAPConnectionManagerImpl();
		final String searchFilter = "cn=Thiru";
		final String searchBase = "o=ldapOrg,c=us";

		try{
			
			DirContext dirCtx = jndiManager.getLDAPDirContext();
			if (getSearchResult(dirCtx, searchFilter, searchBase)) {
				System.out.println("** FOUND ** "); 
			}else{
				System.out.println("** NOT FOUND ** ");
			}

			jndiManager.disConnectLDAPConnection(dirCtx);
			
		}catch(NamingException exception){
			System.out.println("**** Error ****");
			exception.printStackTrace();
			System.exit(0);
		}
	}
	
	/**
	 * This method is used to search an entry in LDAP using Novell API
	 * @param dirContext
	 * @param searchFilter
	 * @param searchBase
	 * @return {@link Boolean}
	 * @throws NamingException
	 */
	private static final boolean getSearchResult(final DirContext dirContext, 
			final String searchFilter, 
			final String searchBase) throws NamingException{
		
		boolean retVal = false;
		
		final SearchControls constraints = new SearchControls();
		constraints.setSearchScope(LDAPConstants.SUBTREE_SCOPE);
		
		System.out.println("** Search Starts : "  + System.currentTimeMillis());
	    final NamingEnumeration searchResults = dirContext.search(searchBase,searchFilter,constraints);
	    System.out.println("** Search Ends : "  + System.currentTimeMillis());
	    
	    if(searchResults != null && searchResults.hasMore()){
	    	retVal= true;
	    	// For Example , displayed attribute values
	    	final SearchResult searchResult = (SearchResult)searchResults.next();
	    	displayAttributes(searchResult.getAttributes());
	    }

		return retVal;
	}
    
	/**
	 * This method used to display the Attribute Values
	 * @param attributes
	 * @throws NamingException
	 */
	private static void displayAttributes(final Attributes attributes) throws NamingException{
        
		if (attributes == null) {
            System.out.println("*** No attributes ***");
        } 
		else {
            for (NamingEnumeration enums = attributes.getAll(); enums.hasMore();) {
                final Attribute attribute = (Attribute)enums.next();
                System.out.println("Id :" + attribute.getID());
                for (NamingEnumeration namingEnu = attribute.getAll();namingEnu.hasMore();)
                    System.out.println("\t        = " + namingEnu.next());
            }
    
        }
	}

}
