/**
 * 
 */
package com.article.ldap.novell.examples;

import com.article.ldap.novell.connection.NovellLDAPConnectionManager;
import com.article.ldap.novell.connection.NovellLDAPConnectionManagerImpl;
import com.novell.ldap.LDAPAttribute;
import com.novell.ldap.LDAPAttributeSet;
import com.novell.ldap.LDAPConnection;
import com.novell.ldap.LDAPEntry;
import com.novell.ldap.LDAPException;

/**
 * @author 		R. Thiru Ganesh Kumar
 * $name: 		CreateEntry.java     
 * $description:This example used to create an entry in LDAP Server using Novell API
 *              adding new entry under people group. 
 * 				  
 */
public class CreateEntry {

	/**
	 * This method used to add en entry in to LDAP Server under people
	 * @param args
	 */
	public static void main(String[] args) {
		final NovellLDAPConnectionManager novellConnManager = new NovellLDAPConnectionManagerImpl();
		final String groupDN = "ou=people,o=ldapOrg,c=us";
		try{
			//Get the LDAPConnection
			final LDAPConnection lConn = novellConnManager.getLDAPConnection();
			lConn.add( getLDAPEntry(groupDN) );
			novellConnManager.disConnectLDAPConnection(lConn);
			System.out.println("** Entry added **");
		}catch(LDAPException exception){
			System.out.println("**** Error ****");
			exception.printStackTrace();
			System.exit(0);
		}

	}
	
	/**
	 * This method used to return an LDAP entry object.
	 * @param group
	 * @return {@link LDAPEntry}
	 */
	private static final LDAPEntry getLDAPEntry(final String group){
        
        final LDAPAttributeSet attributeSet = new LDAPAttributeSet();
        //new String("inetOrgPerson"))
        attributeSet.add( new LDAPAttribute("objectclass", new String[]{"inetOrgPerson", "top", "organizationalPerson" ,"person"}) );                
        //Common Name cn must match in DN's CN
        attributeSet.add( new LDAPAttribute("cn",new String("Thiru")));                
        attributeSet.add( new LDAPAttribute("givenname",new String[]{"Thiru", "Ganesh", "Thiru Ganesh" }));        
        attributeSet.add( new LDAPAttribute("sn", new String("Ramalingam")));        
        attributeSet.add( new LDAPAttribute("telephonenumber",new String("+91 9840281277")));                                                     
        attributeSet.add( new LDAPAttribute("mail",new String("thiru@novellapi.com")));
        attributeSet.add( new LDAPAttribute("userpassword",new String("article")));                                           
        
        final String  dn  = "cn=Thiru," + group;      
        final LDAPEntry retValue = new LDAPEntry( dn, attributeSet ); 
        
        return retValue;

	}
}
