/**
 * 
 */
package com.article.ldap.novell.examples;

import com.article.ldap.LDAPConstants;
import com.article.ldap.novell.connection.NovellLDAPConnectionManager;
import com.article.ldap.novell.connection.NovellLDAPConnectionManagerImpl;
import com.novell.ldap.LDAPConnection;
import com.novell.ldap.LDAPEntry;
import com.novell.ldap.LDAPException;
import com.novell.ldap.LDAPSearchResults;

/**
 * @author 		R. Thiru Ganesh Kumar
 * $name: 		SearchEntry.java     
 * $description:This example used to search an entry in LDAP Server using Novell API
 *              search an entry under people group. 
 * 				  
 */
public class SearchEntry {

	/**
	 * This method used to search an entry in LDAP Server.
	 * @param args
	 */
	public static void main(String[] args) {
		
		final NovellLDAPConnectionManager novellConnManager = new NovellLDAPConnectionManagerImpl();
		final String searchFilter = "cn=Thiru";
		final String searchBase = "o=ldapOrg,c=us";
		try{
			//Get the LDAPConnection
			final LDAPConnection lConn = novellConnManager.getLDAPConnection();
			
			if (getSearchResult(lConn, searchFilter, searchBase)) {
				System.out.println("** FOUND ** "); 
			}else{
				System.out.println("** NOT FOUND ** ");
			}

		}catch(LDAPException exception){
			System.out.println("**** Error ****");
			exception.printStackTrace();
			System.exit(0);
		}
	}

	/**
	 * This method is used to search an entry in LDAP using Novell API
	 * @param lConnection
	 * @param searchFilter
	 * @param searchBase
	 * @return {@link Boolean}
	 * @throws LDAPException
	 */
	private static final boolean getSearchResult(final LDAPConnection lConnection, 
			final String searchFilter, 
			final String searchBase) throws LDAPException{
		
		boolean retVal = false;
		System.out.println("** Search Starts : "  + System.currentTimeMillis());
		final LDAPSearchResults searchResults =
			lConnection.search(
					searchBase,
					LDAPConstants.SCOPE_SUB,
					searchFilter,
					null,
					false);
		System.out.println("** Search Ends : "  + System.currentTimeMillis());
		if (searchResults != null && searchResults.hasMore()) {
			// For Example , displayed only one attribute value 
			LDAPEntry entry = searchResults.next();
			System.out.println("Mail.: " + entry.getAttribute("mail"));
			retVal= true; 
		}
		return retVal;
	}
}
